package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.ScoreRoomDetail;

/**
 * 【请填写功能名称】Mapper接口
 *
 * @author ruoyi
 * @date 2025-10-30
 */
public interface ScoreRoomDetailMapper
{
    /**
     * 查询【请填写功能名称】
     *
     * @param detailId 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public ScoreRoomDetail selectScoreRoomDetailByDetailId(Long detailId);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param scoreRoomDetail 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<ScoreRoomDetail> selectScoreRoomDetailList(ScoreRoomDetail scoreRoomDetail);

    /**
     * 新增【请填写功能名称】
     *
     * @param scoreRoomDetail 【请填写功能名称】
     * @return 结果
     */
    public int insertScoreRoomDetail(ScoreRoomDetail scoreRoomDetail);

    /**
     * 修改【请填写功能名称】
     *
     * @param scoreRoomDetail 【请填写功能名称】
     * @return 结果
     */
    public int updateScoreRoomDetail(ScoreRoomDetail scoreRoomDetail);

    /**
     * 删除【请填写功能名称】
     *
     * @param detailId 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteScoreRoomDetailByDetailId(Long detailId);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param detailIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteScoreRoomDetailByDetailIds(Long[] detailIds);
}
